@@ -1,4 +1,5 @@
-import {CommonKey} from 'system/types/common'
+import {EntityDateTime} from 'system/types/api'
+import {CommonKey, UuidKey} from 'system/types/common'
 
 export type AaaAuthorizationSession = {
   token: string
@@ -19,7 +20,7 @@ export type AaaAuthorizationSession = {
 }
 
 export type AaaSessionUser = {
-  id: string
+  id: UuidKey
   login: string
   firstName: string
   middleName: string
@@ -39,7 +40,7 @@ export const localStorageAuthorizationKeyname: string = 'system.aaa.authorizatio
 export const localStorageUsernameRememberKeyname: string = "system.aaa.rememberedUsername"
 
 export type UserEditModel = {
-  id: string | null
+  id: UuidKey | null
   login: string
   secret: string | null
   locked: boolean
@@ -53,15 +54,24 @@ export type UserEditModel = {
   comments: string
   fullName: string
   avatar: string | null
+  roles: UuidKey[]
+}
+
+export type UserModel = UserEditModel & {
+  id: UuidKey
 }
 
 export type RoleEditModel = {
-  id: string | null
+  id: UuidKey | null
   name: string
   permissions: string[]
   users: CommonKey[]
 }
 
+export type RoleModel = RoleEditModel & {
+  id: UuidKey
+}
+
 export type ActiveDirectoryDomainModel = {
   id: string | null
   enabled: boolean
@@ -70,3 +80,10 @@ export type ActiveDirectoryDomainModel = {
   domain: string
   server: string
 }
+
+export type SessionLogModel = {
+  id: number
+  userId: UuidKey
+  ts: EntityDateTime
+  extra: any
+}
