@@ -1,10 +1,10 @@
 """ A shortcut for make targets for full frontend generation """
 
 from typing import *
-from . import assets, screens, react
+from . import assets, prefront, react
 
 
 def run(roots: List[str]) -> None:
     assets.run(roots)
-    screens.run()
+    prefront.run()
     react.run()
