@@ -1,4 +1,4 @@
-from ...urls import media_res_url
+from ...urls import asset_url
 from ...l10n import lazy_gettext
 
 
@@ -9,7 +9,7 @@ __all__ = [
     'PERMISSION'
 ]
 
-APP_ICON = media_res_url('icons/mail-accounts.png')
+APP_ICON = asset_url('icons/mail-accounts.png')
 
 MSG_APP_CAPTION = lazy_gettext("Mails", 'system.mail')
 MSG_PERMISSION = lazy_gettext("Administer mails", 'system.mail')
