@@ -1,14 +1,14 @@
 from ...l10n import lazy_gettext
-from ...urls import media_res_url
+from ...urls import asset_url
 
 
-APP_ICON: str = media_res_url('icons/settings.png')
+APP_ICON: str = asset_url('icons/settings.png')
 APP_ID: str = 'settings'
 APP_CAPTION = lazy_gettext("Settings & properties", 'system.settings')
 
 SITEMAP_CAPTION = lazy_gettext("Administering", 'system.settings')
 PROPS_CAPTION = lazy_gettext("Settings", 'system.settings')
-PROPS_ICON = media_res_url('icons/props.png')
+PROPS_ICON = asset_url('icons/props.png')
 
 PERMISSION_ADMINISTERING_CAPTION = lazy_gettext("Access the administering", 'system.settings')
 PERMISSION_PROPS_CAPTION = lazy_gettext("Access properties of the project", 'system.settings')
