@@ -2,12 +2,16 @@ from typing import *
 from ...models import Session, SettingsCatalog
 from ..const.aaa import SETTINGS_REMEMBER_USERNAME
 from ... import config, api, l10n, settings, ui
-from ...requests import Request, JSONResponse
+from ...requests import Request, JSONResponse, HTTPException
 from ...runtime import context
 
 
 @api.handle_get('instantiate')
 async def instantiate(request: Request) -> JSONResponse:
+    """ Responses to the frontend with the current user's environment context, like
+    localization parameeters, session information, some configuration etc.
+    """
+
     session: Session = context['session']
     aaa_settings: SettingsCatalog = await settings.get('system.aaa')
 
@@ -30,3 +34,22 @@ async def instantiate(request: Request) -> JSONResponse:
         }
     }
     return JSONResponse(response)
+
+
+@api.handle_get('ui/screens/managed/on_render/{name}')
+async def render_managed_screen(request: Request) -> JSONResponse:
+    """ Used to prepare the managed screen props on the screen render. This
+    controller calls from the frontend on every managed screen open and prior
+    to that screen been rendered.
+    """
+
+    screen_name: str = request.path_params['name']
+    screen: ui.screens.ManagedScreen = ui.screens.get_screen_instance(screen_name)
+
+    if screen is None:
+        raise HTTPException(404)
+
+    if not hasattr(screen, 'on_render'):
+        raise HTTPException(500)
+
+    return JSONResponse(await screen.on_render())
