@@ -1,8 +1,7 @@
 from starlette.requests import Request
-from starlette.routing import Route
 from starlette.exceptions import HTTPException
 from starlette_context import context
-from .routing import route, is_static_path
+from .routing import route, is_static_path, Route
 from .responses import *
 from . import routing, responses
 
